@@ -20,6 +20,8 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
+echo "---- in preprocessing ----"
+echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
@@ -30,7 +32,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-l10n-et
 libreoffice-help-et
-libreoffice-gtk2
+libreoffice-gtk
 </install_package_names>
 
 <postinstall>
@@ -45,7 +47,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-l10n-et
 libreoffice-help-et
-libreoffice-gtk2
+libreoffice-gtk
 </uninstall_package_names>
 
 </app>
