@@ -20,6 +20,8 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
+echo "---- in preprocessing ----"
+echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
