@@ -10,7 +10,7 @@ Kernel-antiX_32bit_legacy_LTS_meltdown_patched
 </name>
 
 <description>  
-antiX Kernel 32 bit Meltdown, Spectre and Foreshadow patched LTS (4.4.264-686-pae)
+antiX Kernel 32 bit Meltdown, Spectre and Foreshadow patched LTS (4.4.0-276-686-pae)
 </description>
 
 <installable>
@@ -23,8 +23,8 @@ antiX Kernel 32 bit Meltdown, Spectre and Foreshadow patched LTS (4.4.264-686-pa
 </preinstall>
 
 <install_package_names>
-linux-image-4.4.264-antix.1-686-smp-pae
-linux-headers-4.4.264-antix.1-686-smp-pae
+linux-image-4.4.0-276-antix.1-686-smp-pae
+linux-headers-4.4.0-276-antix.1-686-smp-pae
 libelf-dev
 libc6-dev
 </install_package_names>
@@ -34,8 +34,8 @@ libc6-dev
 </postinstall>
 
 <uninstall_package_names>
-linux-image-4.4.264-antix.1-686-smp-pae
-linux-headers-4.4.264-antix.1-686-smp-pae
+linux-image-4.4.0-276-antix.1-686-smp-pae
+linux-headers-4.4.0-276-antix.1-686-smp-pae
 </uninstall_package_names>
 
 </app>
